package fr.uca.iut.clfreville2.model.sensor;

import fr.uca.iut.clfreville2.model.sensor.auto.AutoUpdateStrategy;
import fr.uca.iut.clfreville2.model.shared.Tickable;
import javafx.beans.property.DoubleProperty;
import javafx.beans.property.ReadOnlyDoubleProperty;
import javafx.beans.property.SimpleDoubleProperty;

import static java.util.Objects.requireNonNull;

/**
 * A sensor that automatically create new temperatures.
 */
public class AutoSensor extends Sensor implements Tickable {

    private final DoubleProperty temperature = new SimpleDoubleProperty();
    private AutoUpdateStrategy updateStrategy;

    public AutoSensor(int id, String name, AutoUpdateStrategy updateStrategy) {
        super(id, name);
        this.updateStrategy = requireNonNull(updateStrategy, "update strategy");
    }

    @Override
    public void tick() {
        temperature.set(updateStrategy.nextValue(this));
    }

    @Override
    public ReadOnlyDoubleProperty temperatureProperty() {
        return temperature;
    }

    public AutoUpdateStrategy getUpdateStrategy() {
        return updateStrategy;
    }

    public void setUpdateStrategy(AutoUpdateStrategy updateStrategy) {
        this.updateStrategy = requireNonNull(updateStrategy, "update strategy");
    }
}
